referrerpolicy=no-referrer-when-downgrade

DownwardMessageQueuePages

Type Alias DownwardMessageQueuePages 

pub type DownwardMessageQueuePages<T: Config> = StorageDoubleMap<_GeneratedPrefixForStorageDownwardMessageQueuePages<T>, Blake2_128Concat, Id, Twox64Concat, PageIndex, InboundDownwardMessage<BlockNumberFor<T>>, OptionQuery>;
Linked message data list to hold inbound downward message pages.

Messages are not packed and one page is equivalent to one message. DO NOT MODIFY manually. Only use InboundDownwardQueue to preserve invariants.

Storage type is [StorageDoubleMap] with key1 type ParaId, key2 type PageIndex and value type InboundDownwardMessage < BlockNumberFor < T > >.

Aliased Type

pub struct DownwardMessageQueuePages<T: Config>(/* private fields */);